@@ -14,9 +14,11 @@ COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER I
 ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 .. codeauthor:: Radu Viorel Cosnita <radu.cosnita@gmail.com>
+.. py:module:: fantastico.mvc
 '''
 
 from fantastico.exceptions import FantasticoDbError
+from fantastico.utils.singleton import Singleton
 from sqlalchemy import create_engine
 from sqlalchemy.engine.url import URL
 from sqlalchemy.ext.declarative import declarative_base
@@ -30,13 +32,7 @@ class DbSessionManager(object):
     for the whole request.'''
 
     ENGINE = None
-
-    class ConnectionData(object):
-        '''This class is responsible for description the connection data descriptor.'''
-
-        def __init__(self, session, engine):
-            self.session = session
-            self.engine = engine
+    SESSION = None
 
     def __init__(self, db_config, echo=False, create_engine_fn=None, create_session_fn=None):
         try:
@@ -45,6 +41,7 @@ class DbSessionManager(object):
             raise FantasticoDbError(ex)
 
         self._echo = echo
+        self._engine_params = db_config.get("additional_engine_settings", {})
         self._create_engine_fn = create_engine_fn
         self._create_session_fn = create_session_fn
 
@@ -66,28 +63,26 @@ class DbSessionManager(object):
     def get_connection(self, request_id):
         '''This method is responsible for retrieving an active session for the given request.'''
 
-        conn = self._cached_conns.get(request_id)
-        session = None
+        session = self._cached_conns.get(request_id)
 
-        if conn:
-            return conn.session
+        if session:
+            return session
 
         try:
             conn_data = URL(**self._conn_props)
 
             if not DbSessionManager.ENGINE:
-                DbSessionManager.ENGINE = self._create_engine_fn(conn_data, echo=self._echo)
+                DbSessionManager.ENGINE = self._create_engine_fn(conn_data,
+                                                                 echo=self._echo, **self._engine_params)
+                DbSessionManager.SESSION = sessionmaker(bind=DbSessionManager.ENGINE)
 
-            session = self._create_session_fn(sessionmaker(bind=DbSessionManager.ENGINE))
+            session = self._create_session_fn(DbSessionManager.SESSION, lambda: request_id)
 
-            conn = DbSessionManager.ConnectionData(session, DbSessionManager.ENGINE)
-
-            self._cached_conns[request_id] = conn
+            self._cached_conns[request_id] = session
 
             return session
         except Exception as ex:
-            if session:
-                session.remove()
+            self.close_connection(request_id)
 
             raise FantasticoDbError(ex)
 
@@ -96,12 +91,13 @@ class DbSessionManager(object):
         once per request cycle. Fantastico framework does this automatically at the end of each request cycle so you don't have
         to call this manually.'''
 
-        conn = self._cached_conns.get(request_id)
+        session = self._cached_conns.get(request_id)
 
-        if not conn:
+        if not session:
             return
 
-        conn.session.remove()
+        session.remove()
+        session.close()
 
         del self._cached_conns[request_id]
 
@@ -114,6 +110,4 @@ def init_dm_db_engine(db_config, echo=False, create_engine_fn=None, create_sessi
     create_engine_fn = create_engine_fn or create_engine
     create_session_fn = create_session_fn or scoped_session
 
-    global CONN_MANAGER
-
-    CONN_MANAGER = DbSessionManager(db_config, echo, create_engine_fn, create_session_fn)
+    return Singleton()(DbSessionManager(db_config, echo, create_engine_fn, create_session_fn))
